@@ -262,18 +262,18 @@ def process_content_by_type(content, filename: str, llm=None, chunking_config=No
                 loader_kwargs = loader_config['kwargs']
                 # Determine which loader configuration keys are allowed to be overridden by user input.
                 # If 'allowed_to_override' is specified in the loader configuration, use it; otherwise, allow all keys in loader_kwargs.
-                allowed_to_override = loader_config.get('allowed_to_override', list(loader_kwargs.keys()))
+                allowed_to_override = loader_config.get('allowed_to_override', loader_kwargs)
                 # If a chunking_config is provided and contains custom configuration for the current file extension,
-                # update loader_kwargs with user-supplied values, but only for keys explicitly permitted in allowed_to_override.
+                # update loader_kwargs with user-supplied values, but only for keys explicitly permitted in allowed_to_override and if value differs from default.
                 # This ensures that only safe and intended parameters can be customized, preventing accidental or unauthorized changes
                 # to critical loader settings.
                 if chunking_config and (users_config_for_extension := chunking_config.get(extension, {})):
-                    for key in set(users_config_for_extension.keys()) & set(allowed_to_override):
-                        loader_kwargs[key] = users_config_for_extension[key]
-                if LoaderProperties.LLM.value in loader_kwargs:
-                    loader_kwargs[LoaderProperties.LLM.value] = llm
-                if LoaderProperties.PROMPT_DEFAULT.value in loader_kwargs:
-                    loader_kwargs.pop(LoaderProperties.PROMPT_DEFAULT.value)
+                    for key in set(users_config_for_extension.keys()) & set(allowed_to_override.keys()):
+                        if users_config_for_extension[key] != allowed_to_override[key]:
+                            loader_kwargs[key] = users_config_for_extension[key]
+                if LoaderProperties.LLM.value in loader_kwargs and loader_kwargs.pop(LoaderProperties.LLM.value):
+                    loader_kwargs['llm'] = llm
+                if LoaderProperties.PROMPT_DEFAULT.value in loader_kwargs and loader_kwargs.pop(LoaderProperties.PROMPT_DEFAULT.value):
                     loader_kwargs[LoaderProperties.PROMPT.value] = image_processing_prompt
                 loader = loader_cls(file_path=temp_file_path, **loader_kwargs)
                 yield from loader.load()
